summaryrefslogtreecommitdiff
path: root/indra/llcommon/llmainthreadtask.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/llcommon/llmainthreadtask.h')
-rw-r--r--indra/llcommon/llmainthreadtask.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/indra/llcommon/llmainthreadtask.h b/indra/llcommon/llmainthreadtask.h
index 28ad62830b..c3ed7fef52 100644
--- a/indra/llcommon/llmainthreadtask.h
+++ b/indra/llcommon/llmainthreadtask.h
@@ -79,20 +79,20 @@ private:
LLEventTimer(0),
mTask(std::forward<CALLABLE>(callable))
{}
- BOOL tick() override
+ bool tick() override
{
// run the task on the main thread, will populate the future
// obtained by get_future()
mTask();
// tell LLEventTimer we're done (one shot)
- return TRUE;
+ return true;
}
// Given arbitrary CALLABLE, which might be a lambda, how are we
// supposed to obtain its signature for std::packaged_task? It seems
// redundant to have to add an argument list to engage result_of, then
// add the argument list again to complete the signature. At least we
// only support a nullary CALLABLE.
- std::packaged_task<typename std::result_of<CALLABLE()>::type()> mTask;
+ std::packaged_task<std::invoke_result_t<CALLABLE>()> mTask;
};
};
@@ -79,20 +79,20 @@ private:
// Given arbitrary CALLABLE, which might be a lambda, how are we
// supposed to obtain its signature for std::packaged_task? It seems
- // redundant to have to add an argument list to engage result_of, then
+ // redundant to have to add an argument list to engage invoke_result_t, then
// add the argument list again to complete the signature. At least we
// only support a nullary CALLABLE.